==> tuia-commercial-center-api-0.0.4-20190613.032719-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/ActivitySkinDataDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto;

import cn.com.duiba.tuia.commercial.center.api.common.BaseDto;

/**
 * ClassName: ActivitySkinDataDto <br/>
 * Function: 活动皮肤Dto. <br/>
 * date: 2017年2月24日 下午2:54:49 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class ActivitySkinDataDto extends BaseDto {

    private static final long serialVersionUID = -4872868154969983034L;

    public static final ActivitySkinDataDto EMPTY_DTO = new ActivitySkinDataDto(true);

    private Long              id;
    private Long              activityId;                              // 活动id
    private Integer           templateType;                            // 模板type <=> 活动类型
    private String            skinType;                                // 皮肤type
    private String            dataJson;
    private Integer           newLayerRate;                            // 新弹层占比
    private Long              aLayerId;                                // a弹层id
    private Long              bLayerId;                                // b弹层id

    public ActivitySkinDataDto() {

    }

    private ActivitySkinDataDto(boolean isEmpty) {
        super(isEmpty);
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getDataJson() {
        return dataJson;
    }

    public void setDataJson(String dataJson) {
        this.dataJson = dataJson;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }

    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }
}

==> tuia-commercial-center-api-1.1.35-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/ActivitySkinDataDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto;

import cn.com.duiba.tuia.commercial.center.api.dto.common.BaseDto;

/**
 * ClassName: ActivitySkinDataDto <br/>
 * Function: 活动皮肤Dto. <br/>
 * date: 2017年2月24日 下午2:54:49 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class ActivitySkinDataDto extends BaseDto {

    private static final long serialVersionUID = -4872868154969983034L;

    public static final ActivitySkinDataDto EMPTY_DTO = new ActivitySkinDataDto(true);

    private Long              id;
    private Long              activityId;                              // 活动id
    private Integer           templateType;                            // 模板type <=> 活动类型
    private String            skinType;                                // 皮肤type
    private String            dataJson;
    private Integer           newLayerRate;                            // 新弹层占比
    private Long              aLayerId;                                // a弹层id
    private Long              bLayerId;                                // b弹层id

    public ActivitySkinDataDto() {

    }

    private ActivitySkinDataDto(boolean isEmpty) {
        super(isEmpty);
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getDataJson() {
        return dataJson;
    }

    public void setDataJson(String dataJson) {
        this.dataJson = dataJson;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }

    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }
}
